=================
Utility Functions
=================

Shannon Entropy
---------------

.. autofunction:: skgstat.util.shannon.shannon_entropy

Cross Validation
----------------

.. autofunction:: skgstat.util.cross_validation.jacknife

Uncertainty Propagation
-----------------------

.. autofunction:: skgstat.util.uncertainty.propagate